//////////////////////////////////////////////////////////////////////
//
// File: delay.c
//
// Author: J F Main.
//
// Description: Fixed delay routines.
//
//   These are fixed delay routines (fixed in location and size).
//   They they only consume 1 byte of RAM - and the delays do not
//   change whatever the code size.
//
//   These delay routines are written in machine code as
//   C uses the stack for comparing the index variable.
//   Since the stack can be anywhere in memory (different
//   methods may be used by the compiler to access a different
//   memory bank i.e. for optimisation).
//
//   So depending on the (total code used the timing delay
//   changes).  Note this is probably only noticable
//   when changing the code to fit between 16F84 (1k) and 16F877 (8k)
//   If you fill the whole of 16F877 then probably won't change.
//
//   N.B. built in routines such as delay_ms(num) do change.
//   (provided by compiler vendor).
//
// Clock: 4MHz
//
// Version: 1.00 - Initial release.
//
// Copyright : Copyright  John Main 2006
//   http://www.best-microcontroller-projects.com
//   Free for non commercial use as long as this entire copyright notice
//   is included in source code and any other documentation.
//
//////////////////////////////////////////////////////////////////////

//////////////////////////////////////////////////////////////////////
// global as easier to manage ?!? i.e. its name
unsigned short CounterA absolute 0x53;

//////////////////////////////////////////////////////////////////////
//
void delay_10_us(void) org 10 {
  asm {
     CLRW
     CLRW
     CLRW
     CLRW
     CLRW
     CLRW
  }
}

//////////////////////////////////////////////////////////////////////
//
void delay_100_us(void) org 20 {

CounterA =  29;     // must init in C so comiler knows these vars are used.

   asm {

      //;PIC Time Delay = 0.0000920 s with Osc = 4 MHz
      //	movlw	D'29'
      	movwf	CounterA
      loop100us: // NB make this label different from all other asm labels!
      	decfsz	CounterA,1
      	goto	loop100us
      //	retlw
   }
   // tune routine to get correct delay.
   asm {
      CLRW
      CLRW
      CLRW
      CLRW
      CLRW
   }
}

//////////////////////////////////////////////////////////////////////
//
void delay_500_us(void) org 40  {

CounterA = 164;     // must init in C so comiler knows these vars are used.

   asm {

//      ;PIC Time Delay = 0.0004970 s with Osc = 4 MHz
//      	movlw	D'164'
      	movwf	CounterA
      loop500us:  // NB make this label different from all other asm labels!
      	decfsz	CounterA,1
      	goto	loop500us
      //	retlw
   }
}





